# ![icon](https://raw.githubusercontent.com/ManuGira/Guibbon/static/docs/images/icon32.png) Guibbon with U ![icon](https://raw.githubusercontent.com/ManuGira/Guibbon/static/docs/images/icon32.png) 

### High-level GUI with an API similar to the HighGUI of OpenCV. 
**If you know how to use the GUI of OpenCV, then you already know how to use Guibbon.**

It allows to display an image and add GUI controllers such as:

 - Sliders (trackbar)
 - Buttons
 - Radio buttons
 - Check boxes
 - Color picker
 - Draggable points and polygons on the displayed image
 - Any custom widget that you write in Tkinter

### Reasons why you want to use Guibbon:

 - It's fast to learn and fast to code.
 - It's using Tkinter which is natively installed in most python distributions
 - Beside Tkinter, it only has 3 dependencies: numpy, opencv-python and pillow
 - It's less than 200 KB
 - You can create your own custom widget.
 
### Links

* Source code hosted on [GitHub](https://github.com/ManuGira/Guibbon)
* Package hosted on [PyPl](https://pypi.org/project/guibbon)